#import "TextItemWithStr.h"

@implementation TextItemWithStr

+ createBegin: aZone
{
  TextItemWithStr *obj = [super createBegin: aZone];

  obj->item = [TextItem createBegin: aZone];

  return obj;
}

-setX: (int)x Y: (int)y
{
  [item setX: x Y: y];

  return self;
}

-(void) setText: (const char *)text Font: (const char *)font 
	CenterFlag:	(BOOL)centerFlag setCanvas: canvas;
{
  str = [String create: [self getZone] setC: text];

  [item setText: [str getC]];
  [item setFont: font];
  [item setCenterFlag: centerFlag];
  [item setCanvas: canvas];
}

- createEnd
{
  item = [item createEnd];

  return [super createEnd];
}

- (int) compare: otherId
{
	long l1, l2;

	if (self == otherId) return 0;
	sscanf ([self getText], "%*s %ld ", &l1);
	sscanf ([otherId getText], "%*s %ld ", &l2);
	if (l1>l2) return -1;
	return l1<l2;
}

- (const char*) getText
{
  return [str getC];
}

-(void) drop
{
  [str drop];
  [item drop];
  [super drop];
}

@end
